@@ -1,5 +1,6 @@
 import logging
 import os
+import platform
 import sys
 import subprocess
 from pathlib import Path
@@ -31,8 +32,11 @@ def _init_jvm():
         try:
             _logger.debug('Checking %s environment variable', PYJNIUS_JAR_STR)
             PYJNIUS_JAR = os.environ[PYJNIUS_JAR_STR]
-        except KeyError as e:
-            _logger.debug('No %s environment variable; falling back to default path', PYJNIUS_JAR_STR)
+        except KeyError:
+            _logger.debug('No %s environment variable', PYJNIUS_JAR_STR)
+        if not PYJNIUS_JAR:
+            # NB: This logic handles both None and empty string cases.
+            _logger.debug('%s still unknown; falling back to default path', PYJNIUS_JAR_STR)
             PYJNIUS_JAR = os.path.join(sys.prefix, 'share', 'pyjnius', 'pyjnius.jar')
         if Path(PYJNIUS_JAR).is_file():
             _logger.debug('%s found at "%s"', PYJNIUS_JAR_STR, PYJNIUS_JAR)
@@ -50,12 +54,19 @@ def _init_jvm():
         try:
             _logger.debug('Checking %s environment variable', JAVA_HOME_STR)
             JAVA_HOME = os.environ[JAVA_HOME_STR]
-        except KeyError as e:
-            _logger.debug('No %s environment variable; checking with Maven', JAVA_HOME_STR)
+        except KeyError:
+            _logger.debug('No %s environment variable', JAVA_HOME_STR)
+        if not JAVA_HOME:
+            # NB: This logic handles both None and empty string cases.
+            _logger.debug('%s still unknown; checking with Maven', JAVA_HOME_STR)
             # attempt to find Java by interrogating maven
             # (which we have because it is needed by jgo)
             try: 
-                mvn = str(subprocess.check_output(['mvn', '-v']))
+                if (platform.system() == 'Windows'):
+                    mvn = str(subprocess.check_output(['mvn.cmd', '-v']))
+                    mvn = mvn.replace('\\r\\n', '\\n') # Fix Windows line breaks.
+                else:
+                    mvn = str(subprocess.check_output(['mvn', '-v']))
             except subprocess.CalledProcessError as e:
                 _logger.error('Unable to import scyjava, could not find Maven')
                 return None
@@ -70,7 +81,7 @@ def _init_jvm():
                     _logger.error('Unable to import scyjava, could not locate jre')
                     return None
             # cut out 'Java home' or 'runtime'
-            begin = mvn.index('/', begin)
+            begin = mvn.index(':', begin) + 2
             end = mvn.index('\\n', begin)
             JAVA_HOME = mvn[begin:end]
         java_path = Path(JAVA_HOME)
@@ -86,6 +97,18 @@ def _init_jvm():
     else:
         _logger.debug('%s found in globals', JAVA_HOME_STR)
 
+    # On Windows, add server subfolder to the PATH so jvm.dll can be found.
+    if (platform.system() == 'Windows'):
+        # Java 9 and later
+        jvm_server_dir = os.path.join(os.environ['JAVA_HOME'], 'bin', 'server')
+        if Path(os.path.join(jvm_server_dir, 'jvm.dll')).is_file():
+            os.environ['PATH'] += ';' + jvm_server_dir
+        else:
+            # Java 8 and earlier
+            jvm_server_dir = os.path.join(os.environ['JAVA_HOME'], 'jre', 'bin', 'server')
+            if Path(os.path.join(jvm_server_dir, 'jvm.dll')).is_file():
+                os.environ['PATH'] += ';' + jvm_server_dir
+
     endpoints = scyjava_config.get_endpoints()
     repositories = scyjava_config.get_repositories()
 
@@ -98,6 +121,7 @@ def _init_jvm():
             '+'.join(endpoints),
             m2_repo=scyjava_config.get_m2_repo(),
             cache_dir=scyjava_config.get_cache_dir(),
+            manage_dependencies=scijava_config.get_manage_deps(),
             repositories=repositories,
             verbose=scyjava_config.get_verbose()
         )
